@@ -4,13 +4,13 @@
 #' all data.table features without significant impact on performance. '`let`'
 #' and '`take`' functions are simplified interfaces for most common data
 #' manipulation tasks.
-#' - To select rows from data: `take_if(mtcars, am==0)`
-#' - To select columns from data: `take(mtcars, am, vs, mpg)`
+#'
+#' - To select rows from data: `rows(mtcars, am==0)`
+#' - To select columns from data: `columns(mtcars, mpg, vs:carb)`
 #' - To aggregate data: `take(mtcars, mean_mpg = mean(mpg), by = am)`
 #' - To aggregate all non-grouping columns: `take_all(mtcars, mean, by = am)`
-#' - To conditionally aggregate all non-grouping columns: `take_all(iris, if(is.numeric(.x)) mean(.x))`
 #' - To aggregate several columns with one summary: `take(mtcars, mpg, hp, fun = mean, by = am)`
-#' - To get total summary skip 'by' argument: `take_all(mtcars, mean)`
+#' - To get total summary skip `by` argument: `take_all(mtcars, mean)`
 #' - Use magrittr pipe '%>%' to chain several operations:
 #' ```
 #'      mtcars %>%
@@ -64,7 +64,8 @@
 #'     let(
 #'         cyl2 = cyl * 2,
 #'         cyl4 = cyl2 * 2
-#'     ) %>% head()
+#'     ) %>%
+#'     head()
 #'
 #' # You can also use let() to remove variables and
 #' # modify existing variables
@@ -72,7 +73,8 @@
 #'     let(
 #'         mpg = NULL,
 #'         disp = disp * 0.0163871 # convert to litres
-#'     ) %>% head()
+#'     ) %>%
+#'     head()
 #'
 #'
 #' # window functions are useful for grouped computations
@@ -100,14 +102,35 @@
 #'     let(cyl = cyl * var) %>%
 #'     head()
 #'
-#' # filter by condition
+#' # select rows
 #' mtcars %>%
-#'     take_if(am==0)
+#'     rows(am==0) %>%
+#'     head()
 #'
-#' # filter by compound condition
+#' # select rows with compound condition
 #' mtcars %>%
-#'     take_if(am==0 & mpg>mean(mpg))
+#'     rows(am==0 & mpg>mean(mpg))
 #'
+#' # select columns
+#' mtcars %>%
+#'     columns(vs:carb, cyl)
+#'
+#' mtcars %>%
+#'     columns(-am, -cyl)
+#'
+#' # regular expression pattern
+#' columns(iris, "^Petal") # variables which start from 'Petal'
+#' columns(iris, "Width$") # variables which end with 'Width'
+#'
+#' # move Species variable to the front
+#' # pattern "^." matches all variables
+#' columns(iris, Species, "^.")
+#'
+#' # pattern "^.*al" means "contains 'al'"
+#' columns(iris, "^.*al")
+#'
+#' # numeric indexing - all variables except Species
+#' columns(iris, 1:4)
 #'
 #' # A 'take' with summary functions applied without 'by' argument returns an aggregated data
 #' mtcars %>%
@@ -175,6 +198,40 @@
 #'     head()
 #' take(mtcars, (new_var) := eval(var))
 #'
+#' ########################################
+#' # variable selection
+#'
+#' # range selection
+#' iris %>%
+#'     let(
+#'         avg = rowMeans(Sepal.Length %to% Petal.Width)
+#'     ) %>%
+#'     head()
+#'
+#' # multiassignment
+#' iris %>%
+#'     let(
+#'         # starts with Sepal or Petal
+#'         multipled1 %to% multipled4 := cols("^(Sepal|Petal)")*2
+#'     ) %>%
+#'     head()
+#'
+#'
+#' mtcars %>%
+#'     let(
+#'         # text expansion
+#'         cols("scaled_{names(mtcars)}") := lapply(cols("{names(mtcars)}"), scale)
+#'     ) %>%
+#'     head()
+#'
+#' # range selection in 'by'
+#' # range selection  + additional column
+#' mtcars %>%
+#'     take(
+#'         res = sum(cols(mpg, disp %to% drat)),
+#'         by = vs %to% gear
+#'     )
+#'
 #' @docType package
 #' @name maditr
 NULL
@@ -198,8 +255,6 @@ magrittr::`%T>%`
 #' @export
 data.table::data.table
 
-#' @export
-data.table::copy
 
 #' @export
 data.table::as.data.table
@@ -209,8 +264,7 @@ data.table::is.data.table
 data.table::last
 #' @export
 data.table::first
-#' @export
-data.table::like
+
 #' @export
 data.table::`%like%`
 #' @export
@@ -242,6 +296,10 @@ data.table::setkey
 #' @export
 data.table::setkeyv
 #' @export
+data.table::setindex
+#' @export
+data.table::setindexv
+#' @export
 data.table::chmatch
 #' @export
 data.table::`%chin%`
